@@ -1,6 +1,6 @@
 from .run_s2p import run_s2p, default_ops
-from .gui import run as run_gui
 from .detection import ROI
+from .version import version
 
 
 name = "suite2p"
