@@ -1,7 +1,7 @@
 from .h5 import h5py_to_binary
 from .nwb import save_nwb, read_nwb
-from .save import combined
+from .save import combined, compute_dydx
 from .sbx import sbx_to_binary
 from .tiff import mesoscan_to_binary, ome_to_binary, tiff_to_binary, generate_tiff_filename, save_tiff
-from .binary import BinaryFile
+from .binary import BinaryFile, BinaryFileCombined
 from .server import send_jobs
