@@ -1,3 +1,3 @@
-from .register import register_binary, sampled_mean
+from .register import register_binary
 from .metrics import get_pc_metrics
 from .zalign import compute_zpos
