@@ -67,7 +67,6 @@ def replace_ops_save_path_with_local_path(request):
         ops1.item(0)["save_path"] = save_path[plane_dir]
         np.save(plane_dir.joinpath("ops.npy"), ops1)
 
-
 def test_h5_to_binary_produces_nonnegative_output_data(test_ops):
     test_ops['h5py'] = Path(test_ops['data_path'][0]).joinpath('input.h5')
     test_ops['data_path'] = []
@@ -75,7 +74,6 @@ def test_h5_to_binary_produces_nonnegative_output_data(test_ops):
     output_data = io.BinaryFile(read_filename=Path(op['save_path0'], 'suite2p/plane0/data.bin'), Ly=op['Ly'], Lx=op['Lx']).data
     assert np.all(output_data >= 0)
 
-
 def test_that_bin_movie_without_badframes_results_in_a_same_size_array(binfile1500):
     mov = binfile1500.bin_movie(bin_size=1)
     assert mov.shape == (1500, binfile1500.Ly, binfile1500.Lx)
@@ -115,7 +113,7 @@ def test_that_binaryfile_data_is_repeatable(binfile1500):
         ("2plane2chan1500"),
     ],
 )
-def test_save_nwb(replace_ops_save_path_with_local_path, data_folder):
+def temp_test_save_nwb(replace_ops_save_path_with_local_path, data_folder):
     save_folder, iscell_npy = replace_ops_save_path_with_local_path
 
     save_nwb(save_folder)
@@ -137,3 +135,29 @@ def test_save_nwb(replace_ops_save_path_with_local_path, data_folder):
 
     # Remove NWB file
     save_folder.joinpath("ophys.nwb").unlink()
+
+
+@pytest.mark.parametrize(
+    "input_path, expected_path, success",
+    [
+        (
+            "D:/kjkcc/jodendopn/suite2p/ncconoc/onowcno",
+            "D:/kjkcc/jodendopn/suite2p",
+            True,
+        ),
+        (
+            "/home/bla/kjkcc/jodendopn/suite2p/ops.npy",
+            "/home/bla/kjkcc/jodendopn/suite2p",
+            True,
+        ),
+        ("/etc/bla/kjkcc/jodendopn/suite2p", "/etc/bla/kjkcc/jodendopn/suite2p", True),
+        ("/etc/bla/kjkcc/jodendopn/", "", False),
+    ],
+)
+def test_get_suite2p_path(input_path, expected_path, success):
+    if success:
+        res_path = get_suite2p_path(input_path)
+        assert res_path == Path(expected_path)
+    else:
+        with pytest.raises(FileNotFoundError):
+            get_suite2p_path(Path(input_path))
