@@ -28,7 +28,7 @@ def compare_list_of_outputs(output_name_list, data_list_one, data_list_two) -> I
                     if k=='ypix' or k=='xpix' or k=='lam':
                         yield np.allclose(gt_dict[k], output_dict[k], rtol=1e-4, atol=5e-2)
         elif output == 'iscell':  # just check the first column; are cells/noncells classified the same way?
-            yield np.array_equal(data1[:, 0], data2[:, 0])
+            yield (data1[:, 0] != data2[:, 0]).sum() < 5
         elif output == 'redcell':
             yield True
         else:
